@@ -41,7 +41,7 @@ class AwsScanner(BaseCloudScanner):
         ]
         logging.getLogger("botocore").setLevel(logging.WARN)
 
-    @elapsed_time
+    @elapsed_time('Scanning AWS live environment took {} seconds')
     def scan(self) -> str:
         account_data_dir = init_directory(self.settings.output_path, self.settings.account_name, self.settings.clean)
         region_dict_list = self._create_regions_file_structure(account_data_dir)
@@ -172,7 +172,7 @@ class AwsScanner(BaseCloudScanner):
             for retries in range(MAX_RETRIES):
                 data = AwsScanner._call_boto_function(output_file, handler, method_to_call, parameters)
                 if not checks or AwsScanner._is_data_passing_check(data, checks):
-                    break
+                    pass
                 elif retries == MAX_RETRIES - 1:
                     raise Exception(
                         "One of the following checks has repeatedly failed: {}".format(
@@ -255,6 +255,8 @@ class AwsScanner(BaseCloudScanner):
             logger.warning("Exception: {}".format(ex))
             call_summary["exception"] = ex
 
+        return data
+
     @staticmethod
     def _call_boto_function(output_file, handler, method_to_call, parameters):
         data = {}
@@ -318,7 +320,7 @@ class AwsScanner(BaseCloudScanner):
                           max_pool_connections=self.settings.max_pool_connections)
         )
 
-        filepath = os.path.join(account_dir, region["RegionName"], f'{runner["Service"]}--{runner["Request"]}')
+        filepath = os.path.join(account_dir, region["RegionName"], f'{runner["Service"]}-{runner["Request"]}')
 
         method_to_call = snakecase(runner["Request"])
         parameter_keys = set()
